#!/usr/bin/env python
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from path import Path 
from jujubigdata import utils
import jujubigdata

dist_config = jujubigdata.utils.DistConfig(filename='dist.yaml', required_keys=['dirs'])


def stop_hbase_master(): 
    hbase_home = dist_config.path('hbase')
    utils.run_as('ubuntu', '{}/bin/hbase-daemon.sh'.format(hbase_home),'stop', 'master')
    
def restart_hbase_master():
    hbase_home = dist_config.path('hbase')
    utils.run_as('ubuntu', '{}/bin/hbase-daemon.sh'.format(hbase_home),'restart', 'master')

def start_hbase_master():
    hbase_home = dist_config.path('hbase')
    utils.run_as('ubuntu', '{}/bin/hbase-daemon.sh'.format(hbase_home),'start', 'master')
    
def stop_hbase_regionserver(): 
    hbase_home = dist_config.path('hbase')
    utils.run_as('ubuntu', '{}/bin/hbase-daemon.sh'.format(hbase_home),'stop', 'regionserver')
    
def restart_hbase_regionserver():
    hbase_home = dist_config.path('hbase')
    utils.run_as('ubuntu', '{}/bin/hbase-daemon.sh'.format(hbase_home),'restart', 'regionserver')

def start_hbase_regionserver():
    hbase_home = dist_config.path('hbase')
    utils.run_as('ubuntu', '{}/bin/hbase-daemon.sh'.format(hbase_home),'start', 'regionserver')
    
def update_etc_hosts_in_place( ip, host):
    found = False
    ip =str(ip)
    host = str(host)
    filename ="/etc/hosts"
    if (not ip) or (not host):
        return
    with Path(filename).in_place() as (reader, writer):
        for line in reader:
            if not found and line.startswith(ip+'\t'):
                found = True
                line = line.replace(line, ip+'\t'+host+'\n')
            writer.write(line)
            
        if not found:
            line = ip+'\t'+host+'\n'
            writer.write(unicode(line, 'utf-8'))

'''
copied and modified from apahe-kafka charm
'''
import json
import subprocess


def get_zookeeper_servers():
    zk_relation = json.loads(subprocess.check_output(
        ["relation-ids", "--format=json", "zookeeper"]))
    if not zk_relation:
        return ""
    else:
        zk_relation = zk_relation[0]
    zks = []
    units_data = subprocess.check_output(
        ['relation-list', '-r', zk_relation, '--format=json'])
    for unit in json.loads(units_data):
        data = json.loads(subprocess.check_output(
            ['relation-get', '-r', zk_relation, '--format=json', '-', unit]))
        #if 'port' not in data:
        #    continue
        zks.append(data['private-address'])
    zks.sort()
    return ",".join(zks)